@@ -239,23 +239,14 @@ void BondWidget::deleteBond()
 
     if (connection) {
         // qCDebug(PLASMA_NM_EDITOR_LOG) << "About to delete bonded connection" << currentItem->text() << uuid;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::questionTwoActions(this,
-#else
-        if (KMessageBox::questionYesNo(this,
-
-#endif
                                             i18n("Do you want to remove the connection '%1'?", connection->name()),
                                             i18n("Remove Connection"),
                                             KStandardGuiItem::remove(),
                                             KStandardGuiItem::cancel(),
                                             QString(),
                                             KMessageBox::Dangerous)
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            == KMessageBox::Yes) {
-#endif
             connection->remove();
             delete currentItem;
             slotWidgetChanged();
@@ -301,3 +292,5 @@ bool BondWidget::isValid() const
 
     return !m_ui->ifaceName->text().isEmpty() && m_ui->bonds->count() > 0;
 }
+
+#include "moc_bondwidget.cpp"
